import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl =
  "https://gist.githubusercontent.com/Manasa891-git/f4e0d4c8bc00a0545d576c678af7179c/raw/b660764e3dcd29d487e48431a7d02a8845cdb93b/earthquake_data.csv"
const width = 960;
const height = 500;
const margin = { top: 20, right: 10, bottom: 20, left: 350 };


const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.mmi = +d['Magnitude - Basic ($)'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 12));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;
 

  const yScale = scaleBand()
    .domain(data.map(d => d.title))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.magnitude)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="red" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.title}
            x={0}
            y={yScale(d.title)}
            width={xScale(d.magnitude)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);